@@ -70,6 +70,13 @@ fn main() {
     };
 
     let mut options = eframe::NativeOptions::default();
+    // Smoother drag/resize on Windows/Linux
+    #[cfg(any(target_os = "windows", target_os = "linux"))]
+    {
+        options.vsync = false;
+        options.run_and_return = false;
+        options.wgpu_options.present_mode = wgpu::PresentMode::AutoNoVsync;
+    }
 
     // Prefer GL only on macOS Intel
     #[cfg(all(target_os = "macos", target_arch = "x86_64"))]
@@ -77,15 +84,19 @@ fn main() {
         options.renderer = eframe::Renderer::Glow;
     }
 
+    // Use default icon on macOS; use bundled PNG elsewhere
     #[cfg(target_os = "macos")]
-    let icon_bytes: &[u8] = include_bytes!("../icon.png");
+    {
+        options.viewport.icon = Some(std::sync::Arc::new(egui::IconData::default()));
+    }
 
     #[cfg(not(target_os = "macos"))]
-    let icon_bytes: &[u8] = include_bytes!("../icon.png");
-
-    let d = eframe::icon_data::from_png_bytes(icon_bytes)
-        .expect("The icon data must be valid");
-    options.viewport.icon = Some(std::sync::Arc::new(d));
+    {
+        let icon_bytes: &[u8] = include_bytes!("../icon.png");
+        let d = eframe::icon_data::from_png_bytes(icon_bytes)
+            .expect("The icon data must be valid");
+        options.viewport.icon = Some(std::sync::Arc::new(d));
+    }
 
     // rt must be kept in scope for channel lifetimes, so we define and then spawn.
     let rt = tokio::runtime::Builder::new_multi_thread()
@@ -524,7 +535,7 @@ fn main() {
         eprintln!("Exited idevice loop!!");
     });
 
-    eframe::run_native("idevice pair", options, Box::new(|_| Ok(Box::new(app)))).unwrap();
+    eframe::run_native(&format!("idevice pair v{}", env!("CARGO_PKG_VERSION")), options, Box::new(|_| Ok(Box::new(app)))).unwrap();
 }
 
 enum GuiCommands {
@@ -609,7 +620,55 @@ impl eframe::App for MyApp {
                         "Failed to connect to usbmuxd! {install_msg}\n\n{idevice_error:#?}"
                     );
                 }
-                GuiCommands::Devices(vec) => self.devices = Some(vec),
+                GuiCommands::Devices(vec) => {
+                    self.devices = Some(vec);
+                    if self.selected_device.is_empty() || 
+                       (self.devices.as_ref().map_or(true, |devs| !devs.contains_key(&self.selected_device))) {
+                        if let Some(devs) = &self.devices {
+                            if devs.len() == 1 {
+                                if let Some((dev_name, dev)) = devs.iter().next() {
+                                    self.selected_device = dev_name.clone();
+
+                                    self.wireless_enabled = None;
+                                    self.dev_mode_enabled = None;
+                                    self.ddi_mounted = None;
+                                    self.device_info = None;
+
+                                    let dev_clone = dev.clone();
+                                    self.idevice_sender
+                                        .send(IdeviceCommands::EnableWireless(dev_clone.clone()))
+                                        .unwrap();
+                                    self.idevice_sender
+                                        .send(IdeviceCommands::CheckDevMode(dev_clone.clone()))
+                                        .unwrap();
+                                    self.idevice_sender
+                                        .send(IdeviceCommands::AutoMount(dev_clone.clone()))
+                                        .unwrap();
+                                    self.idevice_sender
+                                        .send(IdeviceCommands::GetDeviceInfo(dev_clone))
+                                        .unwrap();
+
+                                    self.pairing_file = None;
+                                    self.pairing_file_message = None;
+                                    self.pairing_file_string = None;
+                                    self.installed_apps = None;
+                                    self.device_info = None;
+                                    self.idevice_sender
+                                        .send(IdeviceCommands::InstalledApps((
+                                            dev.clone(),
+                                            self.supported_apps
+                                                .keys()
+                                                .map(|x| x.to_owned())
+                                                .collect(),
+                                        )))
+                                        .unwrap();
+                                    self.validating = false;
+                                    self.validate_res = None;
+                                }
+                            }
+                        }
+                    }
+                }
                 GuiCommands::DeviceInfo(info) => self.device_info = Some(info),
                 GuiCommands::GetDevicesFailure(idevice_error) => {
                     self.devices_placeholder = format!(
@@ -817,14 +876,48 @@ impl eframe::App for MyApp {
                             ui.heading("Load");
                             ui.label("Load the pairing file from the system.");
                             if ui.button("Load").clicked() {
-                                self.pairing_file_message = Some("Loading...".to_string());
-                                self.pairing_file_string = None;
-                                self.idevice_sender
-                                    .send(IdeviceCommands::LoadPairingFile(dev.clone()))
-                                    .unwrap();
+                                #[cfg(not(feature = "generate"))]
+                                {
+                                    let ctrl_down = ui.input(|i| i.modifiers.ctrl || i.modifiers.command);
+                                    if ctrl_down && self.pairing_file.is_some() {
+                                        if let Some(p) = FileDialog::new()
+                                            .set_can_create_directories(true)
+                                            .set_title("Save Pairing File")
+                                            .set_file_name(format!("{}.plist", &dev.udid))
+                                            .save_file()
+                                        {
+                                            if let Err(e) = std::fs::write(
+                                                p,
+                                                self.pairing_file
+                                                    .as_ref()
+                                                    .unwrap()
+                                                    .clone()
+                                                    .serialize()
+                                                    .unwrap(),
+                                            ) {
+                                                self.save_error = Some(e.to_string());
+                                            }
+                                        }
+                                    } else {
+                                        self.pairing_file_message = Some("Loading...".to_string());
+                                        self.pairing_file_string = None;
+                                        self.idevice_sender
+                                            .send(IdeviceCommands::LoadPairingFile(dev.clone()))
+                                            .unwrap();
+                                    }
+                                }
+                                #[cfg(feature = "generate")]
+                                {
+                                    self.pairing_file_message = Some("Loading...".to_string());
+                                    self.pairing_file_string = None;
+                                    self.idevice_sender
+                                        .send(IdeviceCommands::LoadPairingFile(dev.clone()))
+                                        .unwrap();
+                                }
                             }
                         });
                         ui.separator();
+                        #[cfg(feature = "generate")]
                         ui.vertical(|ui| {
                             ui.heading("Generate");
                             ui.label("Generate a new pairing file. This may invalidate old ones.");
@@ -836,6 +929,12 @@ impl eframe::App for MyApp {
                                     .unwrap();
                             }
                         });
+                        #[cfg(not(feature = "generate"))]
+                        ui.vertical(|ui| {
+                            ui.heading("Generation Disabled");
+                            ui.label("This program was built without generation support. Use load instead.");
+                            ui.label("For SideStore or StikDebug, load is what you want.");
+                        });
                     });
                     if let Some(msg) = &self.pairing_file_message {
                         ui.label(msg);
@@ -846,34 +945,37 @@ impl eframe::App for MyApp {
                     if let Some(pairing_file) = &self.pairing_file_string {
                         egui::Grid::new("reee").min_col_width(200.0).show(ui, |ui| {
                             ui.vertical(|ui| {
-                                ui.heading("Save to File");
-                                if let Some(msg) = &self.save_error {
-                                    ui.label(RichText::new(msg).color(Color32::RED));
-                                }
-                                ui.label("Save this file to your computer, and then transfer it to your device manually.");
-                                if ui.button("Save to File").clicked()
-                                    && let Some(p) = FileDialog::new()
-                                        .set_can_create_directories(true)
-                                        .set_title("Save Pairing File")
-                                        .set_file_name(format!("{}.plist", &dev.udid))
-                                        .save_file()
-                                    {
-                                        self.save_error = None;
-                                        if let Err(e) = std::fs::write(
-                                            p,
-                                            self.pairing_file
-                                                .as_ref()
-                                                .unwrap()
-                                                .clone()
-                                                .serialize()
-                                                .unwrap(),
-                                        ) {
-                                            self.save_error = Some(e.to_string());
-                                        }
-                                    
-                                }
+                                #[cfg(feature = "generate")]
+                                {
+                                    ui.heading("Save to File");
+                                    if let Some(msg) = &self.save_error {
+                                        ui.label(RichText::new(msg).color(Color32::RED));
+                                    }
+                                    ui.label("Save this file to your computer, and then transfer it to your device manually.");
+                                    if ui.button("Save to File").clicked()
+                                        && let Some(p) = FileDialog::new()
+                                            .set_can_create_directories(true)
+                                            .set_title("Save Pairing File")
+                                            .set_file_name(format!("{}.plist", &dev.udid))
+                                            .save_file()
+                                        {
+                                            self.save_error = None;
+                                            if let Err(e) = std::fs::write(
+                                                p,
+                                                self.pairing_file
+                                                    .as_ref()
+                                                    .unwrap()
+                                                    .clone()
+                                                    .serialize()
+                                                    .unwrap(),
+                                            ) {
+                                                self.save_error = Some(e.to_string());
+                                            }
+                                        
+                                    }
 
-                                ui.separator();
+                                    ui.separator();
+                                }
                                 ui.heading("Validation");
                                 ui.label("Verify that your pairing file works over LAN. Your device will be searched for over your network.");
                                 ui.add(egui::TextEdit::singleline(&mut self.validation_ip_input).hint_text("OR enter your device's IP..."));
